@@ -28,7 +28,8 @@ __all__ = ["TaurusTrendSet", "TrendCurve"]
 
 import copy
 import numpy
-from taurus.core import TaurusEventType, TaurusTimeVal
+from taurus.core import (TaurusEventType, TaurusTimeVal,
+                         TaurusAttrValue, Quantity)
 from taurus.qt.qtgui.base import TaurusBaseComponent
 from taurus.core.util.containers import ArrayBuffer, LoopList
 from taurus.external.qt import Qt
@@ -252,9 +253,10 @@ class TaurusTrendSet(PlotDataItem, TaurusBaseComponent):
             # https://github.com/hgrecco/pint/issues/509
             ntrends = numpy.size(rvalue.magnitude)
         except AttributeError:
-            # support boolean values
+            # Support bool, int and float values when rvalue has no magnitude
             _v = numpy.array(rvalue)
-            if _v.dtype is numpy.dtype("bool"):
+            if _v.dtype in (numpy.dtype("bool"), numpy.dtype("int"),
+                            numpy.dtype("float")):
                 from taurus.core.units import Quantity
                 rvalue = Quantity(_v)
                 ntrends = _v.size
@@ -394,6 +396,15 @@ class TaurusTrendSet(PlotDataItem, TaurusBaseComponent):
                       all.
         """
         value = self.getModelValueObj(cache=cache)
+        if value is None:
+            # This is intended to show no data when no points are available.
+            # We can get archiving values if available and needed.
+            value = TaurusAttrValue()
+            value.rvalue = Quantity(numpy.nan)
+            value.time = TaurusTimeVal.now()
+            self.warning("The attribute has no an actual value, check either "
+                         "if the attribute exists or the device is down. "
+                         "Or load data from archiving if needed.")
         if cache and value is not None:
             value = copy.copy(value)
             value.time = TaurusTimeVal.now()
